# 🏃 Bookshelf Move

This datapack gives you precise control over entity movement, allowing you to make them move exactly the way you want.

> “There is nothing permanent except change.”
>
> -- Heraclitus

For more details and usage examples, check out the Bookshelf [documentation](https://docs.mcbookshelf.dev/en/latest/modules/move.html).


## 📖 About Bookshelf

This module is part of the [Bookshelf Library](https://docs.mcbookshelf.dev/en/latest/index.html), a modular library datapack designed to simplify complex systems in Minecraft. Explore the full range of modules and discover how Bookshelf can simplify your Minecraft creations!
